@@ -6,12 +6,16 @@ use prettytable::{Cell, Row};
 use std::fmt;
 
 /// Container for inline text diff result. Can be pretty-printed by Display trait.
-#[derive(Debug, PartialEq, Eq)]
+#[derive(Debug, PartialEq)]
 pub struct InlineChangeset<'a> {
     old: Vec<&'a str>,
     new: Vec<&'a str>,
     separator: &'a str,
     highlight_whitespace: bool,
+    insert_style: Style,
+    insert_whitespace_style: Style,
+    remove_style: Style,
+    remove_whitespace_style: Style,
 }
 
 impl<'a> InlineChangeset<'a> {
@@ -21,6 +25,10 @@ impl<'a> InlineChangeset<'a> {
             new,
             separator: "",
             highlight_whitespace: true,
+            insert_style: Colour::Green.normal(),
+            insert_whitespace_style: Colour::White.on(Colour::Green),
+            remove_style: Colour::Red.strikethrough(),
+            remove_whitespace_style: Colour::White.on(Colour::Red),
         }
     }
     /// Highlight whitespaces in case of insert/remove?
@@ -29,6 +37,30 @@ impl<'a> InlineChangeset<'a> {
         self
     }
 
+    /// Style of inserted text
+    pub fn set_insert_style(mut self, val: Style) -> Self {
+        self.insert_style = val;
+        self
+    }
+
+    /// Style of inserted whitespace
+    pub fn set_insert_whitespace_style(mut self, val: Style) -> Self {
+        self.insert_whitespace_style = val;
+        self
+    }
+
+    /// Style of removed text
+    pub fn set_remove_style(mut self, val: Style) -> Self {
+        self.remove_style = val;
+        self
+    }
+
+    /// Style of removed whitespace
+    pub fn set_remove_whitespace_style(mut self, val: Style) -> Self {
+        self.remove_whitespace_style = val;
+        self
+    }
+
     /// Set output separator
     pub fn set_separator(mut self, val: &'a str) -> Self {
         self.separator = val;
@@ -40,31 +72,27 @@ impl<'a> InlineChangeset<'a> {
         basic::diff(&self.old, &self.new)
     }
 
-    fn color_whitespace(&self, bg_color: Colour, style: Style, a: &[&str]) -> String {
-        let mut out = a.join(self.separator);
-        if self.highlight_whitespace {
-            out = out
-                .chars()
-                .map(|i| {
-                    if i.is_whitespace() {
-                        Colour::White.on(bg_color).paint(i.to_string()).to_string()
-                    } else {
-                        style.paint(i.to_string()).to_string()
-                    }
-                })
-                .collect::<Vec<String>>()
-                .join("");
-        }
-        out
+
+    fn apply_style(&self, style: Style, whitespace_style: Style, a: &[&str]) -> String {
+        a.join(self.separator)
+            .chars()
+            .map(|i| {
+                if i.is_whitespace() && self.highlight_whitespace {
+                        whitespace_style.paint(i.to_string()).to_string()
+                } else {
+                    style.paint(i.to_string()).to_string()
+                }
+            })
+            .collect::<Vec<String>>()
+            .join("")
     }
 
     fn remove_color(&self, a: &[&str]) -> String {
-        self.color_whitespace(Colour::Red, Colour::Red.strikethrough(), a)
-
+        self.apply_style(self.remove_style, self.remove_whitespace_style, a)
     }
 
     fn insert_color(&self, a: &[&str]) -> String {
-        self.color_whitespace(Colour::Green, Colour::Green.normal(), a)
+        self.apply_style(self.insert_style, self.insert_whitespace_style, a)
     }
     /// Returns formatted string with colors
     pub fn format(&self) -> String {
@@ -120,7 +148,7 @@ pub fn diff_words<'a>(old: &'a str, new: &'a str) -> InlineChangeset<'a> {
 }
 
 fn color_multilines(color: Colour, s: &str) -> String {
-    s.split("\n")
+    s.split('\n')
         .map(|i| color.paint(i).to_string())
         .collect::<Vec<_>>()
         .join("\n")
@@ -186,31 +214,32 @@ impl<'a> LineChangeset<'a> {
         let mut start = 0;
         let mut stop = a.len();
         if self.trim_new_lines {
-            for i in start..stop {
-                if a[i] != "" {
+            for (index, element) in a.iter().enumerate() {
+                if *element != "" {
                     break;
                 }
-                start = i + 1;
+                start = index + 1;
             }
-            for i in (start..stop).rev() {
-                if a[i] != "" {
+            for (index, element) in a[start..stop].iter().rev().enumerate() {
+                if *element != "" {
                     break;
                 }
-                stop = i;
+                stop = index;
             }
         }
         let out = &a[start..stop];
         if let Some(color) = color {
-            return (
+            (
                 out.iter()
                     .map(|i| color.paint(*i).to_string())
                     .collect::<Vec<String>>()
                     .join("\n")
                     .replace("\t", "    "),
                 start,
-            );
+            )
+        } else {
+            (out.join("\n").replace("\t", "    "), start)
         }
-        (out.join("\n").replace("\t", "    "), start)
     }
     fn prettytable_process_replace(
         &self,
